@@ -423,19 +423,21 @@ class StationAgent:
     # Valid server status values
     VALID_SERVER_STATUS = {"busy", "idle"}
     
-    def __init__(self, station_thread_id: str, graph_thread_id: str, token: str, initial_state: Optional[Dict[str, Any]] = None):
+    def __init__(self, station_thread_id: str, graph_thread_id: str, token: str, initial_state: Optional[Dict[str, Any]] = None, langgraph_token: Optional[str] = None):
         """
-        Initialize the StationAgent with thread IDs and authentication token.
+        Initialize the StationAgent with thread IDs and authentication tokens.
         
         Args:
             station_thread_id (str): Identifier for the station/workflow instance
             graph_thread_id (str): LangGraph thread identifier
-            token (str): Authentication token for API access
+            token (str): Authentication token for SharedState API access
             initial_state (dict, optional): Initial state object to push to SharedState API. Defaults to None.
+            langgraph_token (str, optional): Authentication token for LangGraph API access. Required for uninterrupt functionality.
         """
         self.station_thread_id = station_thread_id
         self.graph_thread_id = graph_thread_id
         self.token = token
+        self.langgraph_token = langgraph_token
         self.base_url = SHARED_STATE_URL
         
         # Set up HTTP session with authentication
@@ -449,11 +451,11 @@ class StationAgent:
         self.state = self.State(self)
         self.server = self.Server(self)
         
-        # Push initial state to SharedState API if provided
+        # Handle initial state and server variable initialization
         if initial_state is not None:
             # Ensure initial_state includes server variables
             self.initial_state = initial_state.copy()
-            num_servers =  4  # Default number of servers
+            num_servers = 4  # Default number of servers
             if "server" not in self.initial_state:
                 self.initial_state["server"] = ["idle"] * num_servers
             if "serverThread" not in self.initial_state:
@@ -477,8 +479,35 @@ class StationAgent:
             else:
                 print(f"⚠️ StationAgent initialized but failed to push {len(self.initial_state)} variables to SharedState API")
         else:
+            # No initial state provided - check if server variables exist, if not initialize them
             self.initial_state = None
             print("🆕 StationAgent initialized with no initial state to push")
+            
+            # Check if server variables exist as arrays, if not initialize them
+            server_vars = self.state.get("server")
+            if server_vars is None or not isinstance(server_vars, list):
+                print("⚠️ Server variables not found or not arrays, initializing...")
+                num_servers = 4  # Default number of servers
+                server_initialization = {
+                    "server": ["idle"] * num_servers,
+                    "serverThread": ["idle"] * num_servers,
+                    "serverCheckpoint": ["setup"] * num_servers,
+                    "serverTaskType": ["taskPlaceholder"] * num_servers
+                }
+                
+                # Use direct API call to initialize server variables
+                data = {
+                    "stationThread": self.station_thread_id,
+                    "variables": server_initialization
+                }
+                
+                response = self._make_request("POST", "/shared-state/bulk-upsert", data=data)
+                if response and response.get("success", False):
+                    print("✅ Server variables initialized successfully")
+                else:
+                    print("❌ Failed to initialize server variables")
+            else:
+                print("✅ Server variables already exist as arrays")
     
     def _make_request(self, method: str, endpoint: str, params: Optional[Dict] = None, 
                      data: Optional[Dict] = None, max_retries: int = 3) -> Optional[Dict]:
@@ -630,6 +659,20 @@ class StationAgent:
             if variable_name in self.agent.RESERVED_VARIABLES:
                 raise ValueError(f"Cannot set reserved variable '{variable_name}'. Reserved variables: {self.agent.RESERVED_VARIABLES}")
             
+            return self._set_internal(variable_name, variable_value)
+        
+        def _set_internal(self, variable_name: str, variable_value: Any) -> bool:
+            """
+            Internal method to set variables without reserved variable protection.
+            Used by server management methods to update server variables.
+            
+            Args:
+                variable_name (str): Name of the variable to set
+                variable_value (Any): Value to assign to the variable
+                
+            Returns:
+                bool: True on success, False on failure
+            """
             data = {
                 "stationThread": self.agent.station_thread_id,
                 "attributeName": variable_name,
@@ -676,12 +719,8 @@ class StationAgent:
             if reserved_found:
                 raise ValueError(f"Cannot set reserved variables: {reserved_found}. Reserved variables: {self.agent.RESERVED_VARIABLES}")
             
-            # Automatically add server and serverThread if not present
+            # Don't automatically add server variables - they should be explicitly managed
             variables = json_object.copy()
-            if "server" not in variables:
-                variables["server"] = "idle"  # Always default to valid "idle" status
-            if "serverThread" not in variables:
-                variables["serverThread"] = "idle"
                 
             data = {
                 "stationThread": self.agent.station_thread_id,
@@ -897,15 +936,15 @@ class StationAgent:
             threads[serverIndex] = serverThreadId
             task_types[serverIndex] = serverTaskType
             
-            # Persist changes
-            self.agent.state.set("server", servers)
-            self.agent.state.set("serverCheckpoint", checkpoints)
-            self.agent.state.set("serverThread", threads)
-            self.agent.state.set("serverTaskType", task_types)
+            # Persist changes using internal method to bypass reserved variable protection
+            self.agent.state._set_internal("server", servers)
+            self.agent.state._set_internal("serverCheckpoint", checkpoints)
+            self.agent.state._set_internal("serverThread", threads)
+            self.agent.state._set_internal("serverTaskType", task_types)
 
             return {"status": "loaded", "serverThread": serverThreadId}
 
-        def unload(self, checkpoint: str, index: int = 0) -> Dict:
+        def unload(self, checkpoint: str = "setup", index: int = 0) -> Dict:
             """
             Unload the server and set it to idle.
 
@@ -930,8 +969,8 @@ class StationAgent:
             checkpoints = self.agent.state.get("serverCheckpoint") or ["setup"] * len(servers)
             checkpoints[index] = checkpoint
 
-            self.agent.state.set("server", servers)
-            self.agent.state.set("serverCheckpoint", checkpoints)
+            self.agent.state._set_internal("server", servers)
+            self.state._set_internal("serverCheckpoint", checkpoints)
 
             return {"status": "unloaded"}
 
@@ -974,80 +1013,74 @@ class StationAgent:
                 "serverTaskType": task_types[index]
             }
     
-    def uninterrupt(self, task_type: str) -> Dict:
+    def uninterrupt(self, task_type: str, resume_payload: Any = "nextstep: Proceed") -> Dict:
         """
-        Resumes an interrupted LangGraph execution for a given task type.
+        Resumes an interrupted LangGraph execution by sending a resume command.
 
-        This function retrieves the thread ID, LangGraph URL, and assistant ID
-        from the shared state based on the task_type, then sends a resume
-        command to the LangGraph instance.
+        This function retrieves the necessary IDs and URL from the shared state,
+        then calls `client.runs.wait` with a `Command` object to resume the graph,
+        mirroring the logic from our successful test.
+
+        .. warning::
+            The `assistant_id` stored in the shared state via `state.set('{task_type}_assistant_id', ...)`
+            **MUST** be the graph's UUID (e.g., '5e3ad181-...') and not a friendly name
+            (e.g., 'Station2'). Using a friendly name will result in a 422 Unprocessable
+            Entity error.
 
         Args:
-            task_type (str): The type of task to uninterrupt.
+            task_type (str): The identifier for the task, used to retrieve state
+                             variables (e.g., 'Station2').
+            resume_payload (Any): The payload required by the interrupted node
+                                  to continue. Defaults to "nextstep: Proceed".
 
         Returns:
             Dict: A dictionary containing the result of the operation.
-                  - {"success": True, "message": "...", "response": ...} on success.
-                  - {"success": False, "error": "..."} on failure.
         """
-        print(f"Attempting to uninterrupt task: {task_type}")
+        print(f"Attempting to resume task '{task_type}' with payload: '{resume_payload}'")
         try:
-            from langgraph_sdk import get_sync_client, Command
+            from langgraph_sdk import get_sync_client
+            from langgraph_sdk.schema import Command
         except ImportError as e:
-            error_message = f"Failed to import LangGraph SDK: {str(e)}"
-            print(f"ERROR: {error_message}")
-            return {"success": False, "error": error_message}
+            return {"success": False, "error": f"Failed to import LangGraph SDK: {str(e)}"}
 
-        thread_id_var = f"{task_type}_thread_id"
-        url_var = f"{task_type}_URL"
-        assistant_var = f"{task_type}_Assistant"
-
-        thread_id = self.state.get(thread_id_var)
-        langgraph_url = self.state.get(url_var)
-        assistant_id = self.state.get(assistant_var)
+        # Retrieve required info from shared state
+        thread_id = self.state.get(f"{task_type}_thread_id")
+        langgraph_url = self.state.get(f"{task_type}_url")
+        assistant_id = self.state.get(f"{task_type}_assistant_id") # Must be the UUID
 
         if not all([thread_id, langgraph_url, assistant_id]):
-            missing = []
-            if not thread_id:
-                missing.append(thread_id_var)
-            if not langgraph_url:
-                missing.append(url_var)
-            if not assistant_id:
-                missing.append(assistant_var)
-            error_message = f"Missing required state variables: {', '.join(missing)}"
-            print(f"ERROR: {error_message}")
-            return {"success": False, "error": error_message}
+            missing = [v for v, k in [("thread_id", thread_id), ("url", langgraph_url), ("assistant_id", assistant_id)] if not k]
+            return {"success": False, "error": f"Missing required state variables: {', '.join(missing)}"}
 
-        print(f"Found thread_id: {thread_id}, url: {langgraph_url}, assistant_id: {assistant_id}")
+        if not self.langgraph_token:
+            return {"success": False, "error": "LangGraph token is required for uninterrupt functionality."}
+
+        print(f"Found Config: thread_id={thread_id}, assistant_id={assistant_id}")
 
         try:
-            client = get_sync_client(url=langgraph_url, api_key=self.token)
+            client = get_sync_client(url=langgraph_url, api_key=self.langgraph_token)
             print("Successfully initialized LangGraph client.")
         except Exception as e:
-            error_message = f"Failed to initialize LangGraph client: {str(e)}"
-            print(f"ERROR: {error_message}")
-            return {"success": False, "error": error_message}
+            return {"success": False, "error": f"Failed to initialize LangGraph client: {str(e)}"}
 
         try:
-            resume_payload = {"nextStep": "proceed"}
-            print(f"Resuming run with payload: {resume_payload}")
-
+            print("Calling client.runs.wait() with resume command...")
             resumed_state = client.runs.wait(
                 thread_id,
                 assistant_id,
                 command=Command(resume=resume_payload)
             )
 
-            print(f"Successfully resumed thread: {thread_id}")
+            print(f"Successfully resumed graph for thread: {thread_id}")
             return {
                 'success': True,
                 'thread_id': thread_id,
                 'task_type': task_type,
-                'message': 'Successfully resumed station execution',
+                'message': 'Successfully resumed graph execution.',
                 'response_preview': str(resumed_state)[:200]
             }
         except Exception as e:
-            error_message = f"Error resuming LangGraph execution: {str(e)}"
+            error_message = f"Error resuming graph execution: {str(e)}"
             print(f"ERROR: {error_message}")
             return {"success": False, "error": error_message}
 
